sequencetools.increase_sequence_elements_cyclically_by_addenda
==============================================================

.. autofunction:: abjad.tools.sequencetools.increase_sequence_elements_cyclically_by_addenda.increase_sequence_elements_cyclically_by_addenda
